@@ -4,9 +4,17 @@ import random
 from .reddit import Reddit
 import datetime
 import requests.auth
+from dotenv import load_dotenv
+import os
 
-client_auth = requests.auth.HTTPBasicAuth('isLVlpKPAs1cBQ', 'S5HrQV1oLjXDvs7YPdJ8hkFCN8f0oQ')
-headers = {"Authorization": "bearer fhTdafZI-0ClEzzYORfBSCR7x3M", "User-Agent": "Meon/0.1 by emirsurmen"}
+load_dotenv(".env")
+client_id = os.getenv("CLIENT_ID")
+client_secret = os.getenv("CLIENT_SECRET")
+auth = os.getenv("AUTH")
+user_agent = os.getenv("USER_AGENT")
+
+client_auth = requests.auth.HTTPBasicAuth(client_id, client_secret)
+headers = {"Authorization": auth, "User-Agent": user_agent}
 
 
 class Subreddit:
@@ -33,12 +41,14 @@ class Subreddit:
             request = requests.get(f"https://www.reddit.com/r/{self.subreddit}/hot.json", headers=headers,
                                    auth=client_auth)
             meme = json.loads(request.content)
+
             try:
                 randompost = random.randint(0, meme["data"]["dist"])
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
+
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
             stickied = meme["data"]["children"][randompost]["data"]["stickied"]
             spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
@@ -46,6 +56,13 @@ class Subreddit:
             media = meme["data"]["children"][randompost]["data"]["media"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
+            try:
+                flair_author = meme["data"]["children"][randompost]["data"]["author_flair_text"]
+                flair_post = meme["data"]["children"][randompost]["data"]["link_flair_text"]
+            except IndexError:
+                flair_author = None
+                flair_post = None
+
             if nsfw == "true":
                 nsfw = True
             elif nsfw == "false":
@@ -66,8 +83,10 @@ class Subreddit:
             elif spoiler == "false":
                 spoiler = False
 
-            if media is None:
+            if media == "null":
                 contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
+            elif media:
+                contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
             else:
                 contenttext = meme["data"]["children"][randompost]["data"]["url"]
 
@@ -84,24 +103,36 @@ class Subreddit:
                 author=meme["data"]["children"][randompost]["data"]["author"],
                 post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
                 stickied=stickied,
-                spoiler=spoiler
+                spoiler=spoiler,
+                author_flair=flair_author,
+                post_flair=flair_post,
+                subreddit_subscribers=meme["data"]["children"][randompost]["data"]["subreddit_subscribers"]
             )
         except KeyError:
             request = requests.get(f"https://www.reddit.com/r/{self.subreddit}/hot.json", headers=headers,
                                    auth=client_auth)
             meme = json.loads(request.content)
+
             try:
                 randompost = random.randint(0, meme["data"]["dist"])
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
+
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
             stickied = meme["data"]["children"][randompost]["data"]["stickied"]
             spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
             media = meme["data"]["children"][randompost]["data"]["media"]
             s = meme["data"]["children"][randompost]["data"]["created"]
 
+            try:
+                flair_author = meme["data"]["children"][randompost]["data"]["author_flair_text"]
+                flair_post = meme["data"]["children"][randompost]["data"]["link_flair_text"]
+            except IndexError:
+                flair_author = None
+                flair_post = None
+
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
             if nsfw == "true":
@@ -124,8 +155,10 @@ class Subreddit:
             elif spoiler == "false":
                 spoiler = False
 
-            if media is None:
+            if media == "null":
                 contenttext = meme["data"]["children"][randompost]["data"]["selftext"]
+            elif media:
+                contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
             else:
                 contenttext = meme["data"]["children"][randompost]["data"]["url"]
 
@@ -142,7 +175,10 @@ class Subreddit:
                 author=meme["data"]["children"][randompost]["data"]["author"],
                 post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
                 stickied=stickied,
-                spoiler=spoiler
+                spoiler=spoiler,
+                author_flair=flair_author,
+                post_flair=flair_post,
+                subreddit_subscribers=meme["data"]["children"][randompost]["data"]["subreddit_subscribers"]
             )
 
     def get_top_post(self):
@@ -155,12 +191,14 @@ class Subreddit:
             request = requests.get(f"https://www.reddit.com/r/{self.subreddit}/top.json", headers=headers,
                                    auth=client_auth)
             meme = json.loads(request.content)
+
             try:
                 randompost = random.randint(0, meme["data"]["dist"])
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
+
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
             stickied = meme["data"]["children"][randompost]["data"]["stickied"]
             spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
@@ -168,6 +206,13 @@ class Subreddit:
             media = meme["data"]["children"][randompost]["data"]["media"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
+            try:
+                flair_author = meme["data"]["children"][randompost]["data"]["author_flair_text"]
+                flair_post = meme["data"]["children"][randompost]["data"]["link_flair_text"]
+            except IndexError:
+                flair_author = None
+                flair_post = None
+
             if nsfw == "true":
                 nsfw = True
             elif nsfw == "false":
@@ -188,8 +233,10 @@ class Subreddit:
             elif spoiler == "false":
                 spoiler = False
 
-            if media is None:
+            if media == "null":
                 contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
+            elif media:
+                contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
             else:
                 contenttext = meme["data"]["children"][randompost]["data"]["url"]
 
@@ -206,18 +253,23 @@ class Subreddit:
                 author=meme["data"]["children"][randompost]["data"]["author"],
                 post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
                 stickied=stickied,
-                spoiler=spoiler
+                spoiler=spoiler,
+                author_flair=flair_author,
+                post_flair=flair_post,
+                subreddit_subscribers=meme["data"]["children"][randompost]["data"]["subreddit_subscribers"]
             )
         except KeyError:
             request = requests.get(f"https://www.reddit.com/r/{self.subreddit}/top.json", headers=headers,
                                    auth=client_auth)
             meme = json.loads(request.content)
+
             try:
                 randompost = random.randint(0, meme["data"]["dist"])
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
+
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
             stickied = meme["data"]["children"][randompost]["data"]["stickied"]
             spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
@@ -225,6 +277,13 @@ class Subreddit:
             media = meme["data"]["children"][randompost]["data"]["media"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
+            try:
+                flair_author = meme["data"]["children"][randompost]["data"]["author_flair_text"]
+                flair_post = meme["data"]["children"][randompost]["data"]["link_flair_text"]
+            except IndexError:
+                flair_author = None
+                flair_post = None
+
             if nsfw == "true":
                 nsfw = True
             elif nsfw == "false":
@@ -245,8 +304,10 @@ class Subreddit:
             elif spoiler == "false":
                 spoiler = False
 
-            if media is None:
+            if media == "null":
                 contenttext = meme["data"]["children"][randompost]["data"]["selftext"]
+            elif media:
+                contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
             else:
                 contenttext = meme["data"]["children"][randompost]["data"]["url"]
 
@@ -263,7 +324,10 @@ class Subreddit:
                 author=meme["data"]["children"][randompost]["data"]["author"],
                 post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
                 stickied=stickied,
-                spoiler=spoiler
+                spoiler=spoiler,
+                author_flair=flair_author,
+                post_flair=flair_post,
+                subreddit_subscribers=meme["data"]["children"][randompost]["data"]["subreddit_subscribers"]
             )
 
     def get_new_post(self):
@@ -275,12 +339,14 @@ class Subreddit:
             request = requests.get(f"https://www.reddit.com/r/{self.subreddit}/new.json", headers=headers,
                                    auth=client_auth)
             meme = json.loads(request.content)
+
             try:
                 randompost = random.randint(0, meme["data"]["dist"])
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
+
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
             stickied = meme["data"]["children"][randompost]["data"]["stickied"]
             spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
@@ -288,6 +354,13 @@ class Subreddit:
             media = meme["data"]["children"][randompost]["data"]["media"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
+            try:
+                flair_author = meme["data"]["children"][randompost]["data"]["author_flair_text"]
+                flair_post = meme["data"]["children"][randompost]["data"]["link_flair_text"]
+            except IndexError:
+                flair_author = None
+                flair_post = None
+
             if nsfw == "true":
                 nsfw = True
             elif nsfw == "false":
@@ -308,8 +381,10 @@ class Subreddit:
             elif spoiler == "false":
                 spoiler = False
 
-            if media is None:
+            if media == "null":
                 contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
+            elif media:
+                contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
             else:
                 contenttext = meme["data"]["children"][randompost]["data"]["url"]
 
@@ -326,18 +401,23 @@ class Subreddit:
                 author=meme["data"]["children"][randompost]["data"]["author"],
                 post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
                 stickied=stickied,
-                spoiler=spoiler
+                spoiler=spoiler,
+                author_flair=flair_author,
+                post_flair=flair_post,
+                subreddit_subscribers=meme["data"]["children"][randompost]["data"]["subreddit_subscribers"]
             )
         except KeyError:
             request = requests.get(f"https://www.reddit.com/r/{self.subreddit}/new.json", headers=headers,
                                    auth=client_auth)
             meme = json.loads(request.content)
+
             try:
                 randompost = random.randint(0, meme["data"]["dist"])
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
+
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
             stickied = meme["data"]["children"][randompost]["data"]["stickied"]
             spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
@@ -345,6 +425,13 @@ class Subreddit:
             media = meme["data"]["children"][randompost]["data"]["media"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
+            try:
+                flair_author = meme["data"]["children"][randompost]["data"]["author_flair_text"]
+                flair_post = meme["data"]["children"][randompost]["data"]["link_flair_text"]
+            except IndexError:
+                flair_author = None
+                flair_post = None
+
             if nsfw == "true":
                 nsfw = True
             elif nsfw == "false":
@@ -365,8 +452,10 @@ class Subreddit:
             elif spoiler == "false":
                 spoiler = False
 
-            if media is None:
+            if media == "null":
                 contenttext = meme["data"]["children"][randompost]["data"]["selftext"]
+            elif media:
+                contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
             else:
                 contenttext = meme["data"]["children"][randompost]["data"]["url"]
 
@@ -383,7 +472,10 @@ class Subreddit:
                 author=meme["data"]["children"][randompost]["data"]["author"],
                 post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
                 stickied=stickied,
-                spoiler=spoiler
+                spoiler=spoiler,
+                author_flair=flair_author,
+                post_flair=flair_post,
+                subreddit_subscribers=meme["data"]["children"][randompost]["data"]["subreddit_subscribers"]
             )
 
     def get_controversial_post(self):
@@ -395,12 +487,14 @@ class Subreddit:
             request = requests.get(f"https://www.reddit.com/r/{self.subreddit}/controversial.json", headers=headers,
                                    auth=client_auth)
             meme = json.loads(request.content)
+
             try:
                 randompost = random.randint(0, meme["data"]["dist"])
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
+
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
             stickied = meme["data"]["children"][randompost]["data"]["stickied"]
             spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
@@ -408,6 +502,13 @@ class Subreddit:
             media = meme["data"]["children"][randompost]["data"]["media"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
+            try:
+                flair_author = meme["data"]["children"][randompost]["data"]["author_flair_text"]
+                flair_post = meme["data"]["children"][randompost]["data"]["link_flair_text"]
+            except IndexError:
+                flair_author = None
+                flair_post = None
+
             if nsfw == "true":
                 nsfw = True
             elif nsfw == "false":
@@ -428,8 +529,10 @@ class Subreddit:
             elif spoiler == "false":
                 spoiler = False
 
-            if media is None:
+            if media == "null":
                 contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
+            elif media:
+                contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
             else:
                 contenttext = meme["data"]["children"][randompost]["data"]["url"]
 
@@ -446,18 +549,23 @@ class Subreddit:
                 author=meme["data"]["children"][randompost]["data"]["author"],
                 post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
                 stickied=stickied,
-                spoiler=spoiler
+                spoiler=spoiler,
+                author_flair=flair_author,
+                post_flair=flair_post,
+                subreddit_subscribers=meme["data"]["children"][randompost]["data"]["subreddit_subscribers"]
             )
         except KeyError:
             request = requests.get(f"https://www.reddit.com/r/{self.subreddit}/controversial.json", headers=headers,
                                    auth=client_auth)
             meme = json.loads(request.content)
+
             try:
                 randompost = random.randint(0, meme["data"]["dist"])
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
+
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
             stickied = meme["data"]["children"][randompost]["data"]["stickied"]
             spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
@@ -465,6 +573,13 @@ class Subreddit:
             media = meme["data"]["children"][randompost]["data"]["media"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
+            try:
+                flair_author = meme["data"]["children"][randompost]["data"]["author_flair_text"]
+                flair_post = meme["data"]["children"][randompost]["data"]["link_flair_text"]
+            except IndexError:
+                flair_author = None
+                flair_post = None
+
             if nsfw == "true":
                 nsfw = True
             elif nsfw == "false":
@@ -485,8 +600,10 @@ class Subreddit:
             elif spoiler == "false":
                 spoiler = False
 
-            if media is None:
+            if media == "null":
                 contenttext = meme["data"]["children"][randompost]["data"]["selftext"]
+            elif media:
+                contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
             else:
                 contenttext = meme["data"]["children"][randompost]["data"]["url"]
 
@@ -503,5 +620,8 @@ class Subreddit:
                 author=meme["data"]["children"][randompost]["data"]["author"],
                 post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
                 stickied=stickied,
-                spoiler=spoiler
+                spoiler=spoiler,
+                author_flair=flair_author,
+                post_flair=flair_post,
+                subreddit_subscribers=meme["data"]["children"][randompost]["data"]["subreddit_subscribers"]
             )
