@@ -4,9 +4,17 @@ import random
 from .reddit import Reddit
 import datetime
 import requests.auth
+from dotenv import load_dotenv
+import os
 
-client_auth = requests.auth.HTTPBasicAuth('isLVlpKPAs1cBQ', 'S5HrQV1oLjXDvs7YPdJ8hkFCN8f0oQ')
-headers = {"Authorization": "bearer fhTdafZI-0ClEzzYORfBSCR7x3M", "User-Agent": "Meon/0.1 by emirsurmen"}
+load_dotenv(".env")
+client_id = os.getenv("CLIENT_ID")
+client_secret = os.getenv("CLIENT_SECRET")
+auth = os.getenv("AUTH")
+user_agent = os.getenv("USER_AGENT")
+
+client_auth = requests.auth.HTTPBasicAuth(client_id, client_secret)
+headers = {"Authorization": auth, "User-Agent": user_agent}
 
 
 class User:
@@ -21,12 +29,14 @@ class User:
         try:
             request = requests.get(f"https://www.reddit.com/u/{self.user}/hot.json", headers=headers, auth=client_auth)
             meme = json.loads(request.content)
+
             try:
                 randompost = random.randint(0, meme["data"]["dist"])
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
+
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
             stickied = meme["data"]["children"][randompost]["data"]["stickied"]
             spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
@@ -34,6 +44,13 @@ class User:
             s = meme["data"]["children"][randompost]["data"]["created"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
+            try:
+                flair_author = meme["data"]["children"][randompost]["data"]["author_flair_text"]
+                flair_post = meme["data"]["children"][randompost]["data"]["link_flair_text"]
+            except IndexError:
+                flair_author = None
+                flair_post = None
+
             if nsfw == "true":
                 nsfw = True
             elif nsfw == "false":
@@ -54,8 +71,10 @@ class User:
             elif spoiler == "false":
                 spoiler = False
 
-            if media is None:
+            if media == "null":
                 contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
+            elif media:
+                contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
             else:
                 contenttext = meme["data"]["children"][randompost]["data"]["url"]
 
@@ -70,19 +89,25 @@ class User:
                 pinned=pinned,
                 created_at=updated,
                 author=meme["data"]["children"][randompost]["data"]["author"],
-                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
+                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}"
+                         .replace("https://reddit.com/r/u_", " https://reddit.com/u/"),
                 stickied=stickied,
-                spoiler=spoiler
+                spoiler=spoiler,
+                author_flair=flair_author,
+                post_flair=flair_post,
+                subreddit_subscribers=meme["data"]["children"][randompost]["data"]["subreddit_subscribers"]
             )
         except KeyError:
             request = requests.get(f"https://www.reddit.com/u/{self.user}/hot.json", headers=headers, auth=client_auth)
             meme = json.loads(request.content)
+
             try:
                 randompost = random.randint(0, meme["data"]["dist"])
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
+
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
             stickied = meme["data"]["children"][randompost]["data"]["stickied"]
             spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
@@ -90,6 +115,13 @@ class User:
             s = meme["data"]["children"][randompost]["data"]["created"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
+            try:
+                flair_author = meme["data"]["children"][randompost]["data"]["author_flair_text"]
+                flair_post = meme["data"]["children"][randompost]["data"]["link_flair_text"]
+            except IndexError:
+                flair_author = None
+                flair_post = None
+
             if nsfw == "true":
                 nsfw = True
             elif nsfw == "false":
@@ -110,8 +142,10 @@ class User:
             elif spoiler == "false":
                 spoiler = False
 
-            if media is None:
+            if media == "null":
                 contenttext = meme["data"]["children"][randompost]["data"]["selftext"]
+            elif media:
+                contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
             else:
                 contenttext = meme["data"]["children"][randompost]["data"]["url"]
 
@@ -126,9 +160,13 @@ class User:
                 pinned=pinned,
                 created_at=updated,
                 author=meme["data"]["children"][randompost]["data"]["author"],
-                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
+                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}"
+                         .replace("https://reddit.com/r/u_", " https://reddit.com/u/"),
                 stickied=stickied,
-                spoiler=spoiler
+                spoiler=spoiler,
+                author_flair=flair_author,
+                post_flair=flair_post,
+                subreddit_subscribers=meme["data"]["children"][randompost]["data"]["subreddit_subscribers"]
             )
 
     def get_top_post(self):
@@ -140,12 +178,14 @@ class User:
         try:
             request = requests.get(f"https://www.reddit.com/u/{self.user}/top.json", headers=headers, auth=client_auth)
             meme = json.loads(request.content)
+
             try:
                 randompost = random.randint(0, meme["data"]["dist"])
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
+
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
             stickied = meme["data"]["children"][randompost]["data"]["stickied"]
             spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
@@ -153,6 +193,13 @@ class User:
             s = meme["data"]["children"][randompost]["data"]["created"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
+            try:
+                flair_author = meme["data"]["children"][randompost]["data"]["author_flair_text"]
+                flair_post = meme["data"]["children"][randompost]["data"]["link_flair_text"]
+            except IndexError:
+                flair_author = None
+                flair_post = None
+
             if nsfw == "true":
                 nsfw = True
             elif nsfw == "false":
@@ -173,8 +220,10 @@ class User:
             elif spoiler == "false":
                 spoiler = False
 
-            if media is None:
+            if media == "null":
                 contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
+            elif media:
+                contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
             else:
                 contenttext = meme["data"]["children"][randompost]["data"]["url"]
 
@@ -189,19 +238,25 @@ class User:
                 pinned=pinned,
                 created_at=updated,
                 author=meme["data"]["children"][randompost]["data"]["author"],
-                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
+                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}"
+                         .replace("https://reddit.com/r/u_", " https://reddit.com/u/"),
                 stickied=stickied,
-                spoiler=spoiler
+                spoiler=spoiler,
+                author_flair=flair_author,
+                post_flair=flair_post,
+                subreddit_subscribers=meme["data"]["children"][randompost]["data"]["subreddit_subscribers"]
             )
         except KeyError:
             request = requests.get(f"https://www.reddit.com/u/{self.user}/top.json", headers=headers, auth=client_auth)
             meme = json.loads(request.content)
+
             try:
                 randompost = random.randint(0, meme["data"]["dist"])
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
+
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
             stickied = meme["data"]["children"][randompost]["data"]["stickied"]
             spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
@@ -209,6 +264,13 @@ class User:
             s = meme["data"]["children"][randompost]["data"]["created"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
+            try:
+                flair_author = meme["data"]["children"][randompost]["data"]["author_flair_text"]
+                flair_post = meme["data"]["children"][randompost]["data"]["link_flair_text"]
+            except IndexError:
+                flair_author = None
+                flair_post = None
+
             if nsfw == "true":
                 nsfw = True
             elif nsfw == "false":
@@ -229,8 +291,10 @@ class User:
             elif spoiler == "false":
                 spoiler = False
 
-            if media is None:
+            if media == "null":
                 contenttext = meme["data"]["children"][randompost]["data"]["selftext"]
+            elif media:
+                contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
             else:
                 contenttext = meme["data"]["children"][randompost]["data"]["url"]
 
@@ -245,9 +309,13 @@ class User:
                 pinned=pinned,
                 created_at=updated,
                 author=meme["data"]["children"][randompost]["data"]["author"],
-                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
+                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}"
+                         .replace("https://reddit.com/r/u_", " https://reddit.com/u/"),
                 stickied=stickied,
-                spoiler=spoiler
+                spoiler=spoiler,
+                author_flair=flair_author,
+                post_flair=flair_post,
+                subreddit_subscribers=meme["data"]["children"][randompost]["data"]["subreddit_subscribers"]
             )
 
     def get_new_post(self):
@@ -258,12 +326,14 @@ class User:
         try:
             request = requests.get(f"https://www.reddit.com/u/{self.user}/new.json", headers=headers, auth=client_auth)
             meme = json.loads(request.content)
+
             try:
                 randompost = random.randint(0, meme["data"]["dist"])
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
+
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
             media = meme["data"]["children"][randompost]["data"]["media"]
             stickied = meme["data"]["children"][randompost]["data"]["stickied"]
@@ -271,6 +341,13 @@ class User:
             s = meme["data"]["children"][randompost]["data"]["created"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
+            try:
+                flair_author = meme["data"]["children"][randompost]["data"]["author_flair_text"]
+                flair_post = meme["data"]["children"][randompost]["data"]["link_flair_text"]
+            except IndexError:
+                flair_author = None
+                flair_post = None
+
             if nsfw == "true":
                 nsfw = True
             elif nsfw == "false":
@@ -291,8 +368,10 @@ class User:
             elif spoiler == "false":
                 spoiler = False
 
-            if media is None:
+            if media == "null":
                 contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
+            elif media:
+                contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
             else:
                 contenttext = meme["data"]["children"][randompost]["data"]["url"]
 
@@ -307,19 +386,25 @@ class User:
                 pinned=pinned,
                 created_at=updated,
                 author=meme["data"]["children"][randompost]["data"]["author"],
-                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
+                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}"
+                         .replace("https://reddit.com/r/u_", " https://reddit.com/u/"),
                 stickied=stickied,
-                spoiler=spoiler
+                spoiler=spoiler,
+                author_flair=flair_author,
+                post_flair=flair_post,
+                subreddit_subscribers=meme["data"]["children"][randompost]["data"]["subreddit_subscribers"]
             )
         except KeyError:
             request = requests.get(f"https://www.reddit.com/u/{self.user}/new.json", headers=headers, auth=client_auth)
             meme = json.loads(request.content)
+
             try:
                 randompost = random.randint(0, meme["data"]["dist"])
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
+
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
             stickied = meme["data"]["children"][randompost]["data"]["stickied"]
             spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
@@ -327,6 +412,13 @@ class User:
             s = meme["data"]["children"][randompost]["data"]["created"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
+            try:
+                flair_author = meme["data"]["children"][randompost]["data"]["author_flair_text"]
+                flair_post = meme["data"]["children"][randompost]["data"]["link_flair_text"]
+            except IndexError:
+                flair_author = None
+                flair_post = None
+
             if nsfw == "true":
                 nsfw = True
             elif nsfw == "false":
@@ -347,8 +439,10 @@ class User:
             elif spoiler == "false":
                 spoiler = False
 
-            if media is None:
+            if media == "null":
                 contenttext = meme["data"]["children"][randompost]["data"]["selftext"]
+            elif media:
+                contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
             else:
                 contenttext = meme["data"]["children"][randompost]["data"]["url"]
 
@@ -363,9 +457,13 @@ class User:
                 pinned=pinned,
                 created_at=updated,
                 author=meme["data"]["children"][randompost]["data"]["author"],
-                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
+                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}"
+                         .replace("https://reddit.com/r/u_", " https://reddit.com/u/"),
                 stickied=stickied,
-                spoiler=spoiler
+                spoiler=spoiler,
+                author_flair=flair_author,
+                post_flair=flair_post,
+                subreddit_subscribers=meme["data"]["children"][randompost]["data"]["subreddit_subscribers"]
             )
 
     def get_controversial_post(self):
@@ -377,12 +475,14 @@ class User:
             request = requests.get(f"https://www.reddit.com/u/{self.user}/controversial.json",
                                    headers=headers, auth=client_auth)
             meme = json.loads(request.content)
+
             try:
                 randompost = random.randint(0, meme["data"]["dist"])
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
+
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
             stickied = meme["data"]["children"][randompost]["data"]["stickied"]
             spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
@@ -390,6 +490,13 @@ class User:
             media = meme["data"]["children"][randompost]["data"]["media"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
+            try:
+                flair_author = meme["data"]["children"][randompost]["data"]["author_flair_text"]
+                flair_post = meme["data"]["children"][randompost]["data"]["link_flair_text"]
+            except IndexError:
+                flair_author = None
+                flair_post = None
+
             if nsfw == "true":
                 nsfw = True
             elif nsfw == "false":
@@ -410,8 +517,10 @@ class User:
             elif spoiler == "false":
                 spoiler = False
 
-            if media is None:
+            if media == "null":
                 contenttext = meme["data"]["children"][randompost]["data"]["url_overridden_by_dest"]
+            elif media:
+                contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
             else:
                 contenttext = meme["data"]["children"][randompost]["data"]["url"]
 
@@ -426,20 +535,26 @@ class User:
                 pinned=pinned,
                 created_at=updated,
                 author=meme["data"]["children"][randompost]["data"]["author"],
-                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
+                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}"
+                         .replace("https://reddit.com/r/u_", " https://reddit.com/u/"),
                 stickied=stickied,
-                spoiler=spoiler
+                spoiler=spoiler,
+                author_flair=flair_author,
+                post_flair=flair_post,
+                subreddit_subscribers=meme["data"]["children"][randompost]["data"]["subreddit_subscribers"]
             )
         except KeyError:
             request = requests.get(f"https://www.reddit.com/u/{self.user}/controversial.json", headers=headers,
                                    auth=client_auth)
             meme = json.loads(request.content)
+
             try:
                 randompost = random.randint(0, meme["data"]["dist"])
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
             except IndexError:
                 randompost = 0
                 nsfw = meme["data"]["children"][randompost]["data"]["over_18"]
+
             pinned = meme["data"]["children"][randompost]["data"]["pinned"]
             stickied = meme["data"]["children"][randompost]["data"]["stickied"]
             spoiler = meme["data"]["children"][randompost]["data"]["spoiler"]
@@ -447,6 +562,13 @@ class User:
             media = meme["data"]["children"][randompost]["data"]["media"]
             updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
+            try:
+                flair_author = meme["data"]["children"][randompost]["data"]["author_flair_text"]
+                flair_post = meme["data"]["children"][randompost]["data"]["link_flair_text"]
+            except IndexError:
+                flair_author = None
+                flair_post = None
+
             if nsfw == "true":
                 nsfw = True
             elif nsfw == "false":
@@ -467,8 +589,10 @@ class User:
             elif spoiler == "false":
                 spoiler = False
 
-            if media is None:
+            if media == "null":
                 contenttext = meme["data"]["children"][randompost]["data"]["selftext"]
+            elif media:
+                contenttext = meme["data"]["children"][randompost]["data"]["media"]["oembed"]["thumbnail_url"]
             else:
                 contenttext = meme["data"]["children"][randompost]["data"]["url"]
 
@@ -483,7 +607,11 @@ class User:
                 pinned=pinned,
                 created_at=updated,
                 author=meme["data"]["children"][randompost]["data"]["author"],
-                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}",
+                post_url=f"https://reddit.com{meme['data']['children'][randompost]['data']['permalink']}"
+                         .replace("https://reddit.com/r/u_", " https://reddit.com/u/"),
                 stickied=stickied,
-                spoiler=spoiler
+                spoiler=spoiler,
+                author_flair=flair_author,
+                post_flair=flair_post,
+                subreddit_subscribers=meme["data"]["children"][randompost]["data"]["subreddit_subscribers"]
             )
